@@ -174,7 +174,14 @@ class Conversation:
         with open(file_path, "wb") as file:
             pickle.dump(self, file)
 
-    def summarise(self, force: bool = False, print_summary: bool = True):
+    def summarise(
+        self,
+        force: bool = False,
+        print_summary: bool = True,
+        system_prompt: Optional[str] = None,
+        summary_prompt: Optional[str] = None,
+        append_prompt: Optional[str] = None,
+    ):
         """Generate a summary of the conversation.
 
         Parameters
@@ -183,28 +190,42 @@ class Conversation:
             If True, generate a new summary even if one already exists.
         print_summary : bool
             If True, print the summary to the console.
+        system_prompt : str or None
+            The system prompt to use when generating the summary.
+        summary_prompt : str or None
+            The summary prompt to use when generating the summary.
+        append_prompt : str or None
+            The append prompt to use when generating the summary.
 
         Returns
         -------
         summary : str
             The generated summary.
         """
-        if self._transcription_shortened is None:
-            from .ai._chatgpt import _shorten_transcript
-
-            self._transcription_shortened = _shorten_transcript(self.export_text())
+        short_transcript = self.shortened_transcript()
 
         if (self._summary_automated is None) or force:
             from .ai import summarise
 
-            self._summary_automated = summarise(self._transcription_shortened)
+            self._summary_automated = summarise(
+                short_transcript,
+                system_prompt,
+                summary_prompt,
+                append_prompt,
+            )
 
         if print_summary:
             print(self._summary_automated)
 
         return self._summary_automated
 
-    def query(self, query: str, print_summary: bool = True):
+    def query(
+        self,
+        query: str,
+        print_summary: bool = True,
+        system_prompt: Optional[str] = None,
+        append_prompt: Optional[str] = None,
+    ):
         """Query the conversation.
 
         Parameters
@@ -213,23 +234,43 @@ class Conversation:
             The query to ask the conversation.
         print_summary : bool
             If True, print the summary to the console.
+        system_prompt : str or None
+            The system prompt to use when generating the summary.
+        append_prompt : str or None
+            The append prompt to use when generating the summary.
 
         Returns
         -------
         summary : str
-            The generated summary.
+            The generated query response.
         """
         from .ai import query as query_fn
 
+        short_transcript = self.shortened_transcript()
+
+        answer = query_fn(short_transcript, query, system_prompt, append_prompt)
+        if print_summary:
+            print(answer)
+        return answer
+
+    def shortened_transcript(self) -> str:
+        """
+        Get the shortened transcript of the conversation.
+
+        This method returns the previously shortened transcript if available.
+        If not, it computes the shortened transcript first and then returns it.
+
+        Returns
+        -------
+        str
+            The shortened transcript of the conversation.
+        """
         if self._transcription_shortened is None:
             from .ai._chatgpt import _shorten_transcript
 
             self._transcription_shortened = _shorten_transcript(self.export_text())
 
-        answer = query_fn(self._transcription_shortened, query)
-        if print_summary:
-            print(answer)
-        return answer
+        return self._transcription_shortened
 
 
 def load_conversation(file_path: str) -> "Conversation":
